OC.L10N.register(
    "settings",
    {
    "{actor} added you to group {group}" : "{actor} te agregó al grupo {group}",
    "You added {user} to group {group}" : "Agregaste a {user} al grupo {group}",
    "{actor} added {user} to group {group}" : "{actor} agregó a {user} al grupo {group}",
    "An administrator added you to group {group}" : "Un administrador te agregó al grupo {group}",
    "An administrator added {user} to group {group}" : "Un administrador agregó a {user} al grupo {group}",
    "{actor} removed you from group {group}" : "{actor} te eliminó del grupo {group}",
    "You removed {user} from group {group}" : "Eliminaste a {user} del grupo {group}",
    "{actor} removed {user} from group {group}" : "{actor} eliminó a {user} del grupo {group}",
    "An administrator removed you from group {group}" : "Un administrador te eliminó del grupo {group}",
    "An administrator removed {user} from group {group}" : "Un administrador eliminó a {user} del grupo {group}",
    "Your <strong>group memberships</strong> were modified" : "Tus <strong>pertenencias a grupos</strong> fueron modificadas",
    "{actor} changed your password" : "{actor} cambió tu contraseña",
    "You changed your password" : "Cambiaste tu contraseña",
    "Your password was reset by an administrator" : "Tu contraseña fue restablecida por un adminsitrador",
    "Your password was reset" : "Tu contraseña fue restablecida",
    "{actor} changed your email address" : "{actor} cambió tu dirección de correo electrónico",
    "You changed your email address" : "Cambiaste tu dirección de correo electrónico",
    "Your email address was changed by an administrator" : "Un administrador cambió tu dirección de correo electrónico",
    "You created an app password for a session named \"{token}\"" : "Creaste una contraseña de aplicación para una sesión llamada \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Un administrador creó una contraseña de aplicación para una sesión llamada \"{token}\"",
    "You deleted app password \"{token}\"" : "Eliminaste la contraseña de aplicación \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Cambiaste el nombre de la contraseña de aplicación \"{token}\" a \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Concediste acceso al sistema de archivos a la contraseña de aplicación \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Eliminaste el acceso al sistema de archivos de la contraseña de aplicación \"{token}\"",
    "Security" : "Seguridad",
    "You successfully logged in using two-factor authentication (%1$s)" : "Iniciaste sesión usando autenticación en dos pasos (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Falló el inicio de sesión usando autenticación en dos pasos (%1$s)",
    "Remote wipe was started on %1$s" : "Se inició el borrado remoto de %1$s",
    "Remote wipe has finished on %1$s" : "Terminó el borrado remoto de %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Tu <strong>contraseña</strong> o <strong>dirección de correo electrónico</strong> fue modificada",
    "Settings" : "Configuración",
    "Could not remove app." : "No se pudo eliminar la aplicación.",
    "Could not update app." : "No se pudo actualizar la aplicación.",
    "Wrong password" : "Contraseña incorrecta",
    "Unable to change personal password" : "No se pudo cambiar la contraseña personal",
    "Saved" : "Guardado",
    "No Login supplied" : "No se especificó un usuario",
    "Unable to change password" : "No fue posible cambiar la contraseña",
    "Unable to change password. Password too long." : "No se pudo cambiar la contraseña. La contraseña es demasiado larga.",
    "Authentication error" : "Error de autenticación",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Por favor proporcioná una contraseña de recuperación de administrador; de lo contrario, toda la información de la cuenta se perderá.",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación del administrador incorrecta. Por favor verificala e intentalo de nuevo.",
    "Backend does not support password change, but the encryption of the account key was updated." : "El backend no admite el cambio de contraseña, pero se actualizó la clave de cifrado del usuario.",
    "Administrator documentation" : "Documentación del administrador",
    "User documentation" : "Documentación del usuario",
    "Nextcloud help overview" : "Vista general de la ayuda de Nextcloud",
    "Invalid SMTP password." : "Constraseña SMTP inválida. ",
    "Email setting test" : "Prueba de configuración de correo",
    "Well done, %s!" : "¡Bien hecho, %s!",
    "If you received this email, the email configuration seems to be correct." : "Si recibiste este correo electrónico, la configuración de correo electrónico parece ser correcta.",
    "Email could not be sent. Check your mail server log" : "No se pudo enviar el correo electrónico. Comprobá el registro del servidor de correo electrónico",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Hubo un problema al enviar el correo electrónico. Por favor revisá tus configuraciones (Error: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Necesitás configurar tu correo electrónico antes de poder enviar mensajes de prueba. Para hacerlo, visitá %s.",
    "Recently active" : "Activos recientemente",
    "Disabled accounts" : "Cuentas deshabilitadas",
    "Invalid account" : "Cuenta inválida",
    "Invalid mail address" : "Dirección de correo electrónico inválida",
    "Settings saved" : "Configuraciones guardadas",
    "Unable to change full name" : "No se pudo cambiar el nombre completo",
    "Unable to change email address" : "No se pudo cambiar la dirección de correo electrónico",
    "Unable to set invalid phone number" : "No se pudo guardar un número de teléfono inválido",
    "Unable to set invalid website" : "No se pudo guardar una página web inválida",
    "Some account data was invalid" : "Algunos datos de la cuenta son inválidos",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Para poder verificar tu cuenta de Twitter, posteá el siguiente tweet en Twitter (por favor asegurate de postear sin saltos de línea):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Para poder verificar tu sitio Web, agregá el siguiente contenido a tu web-root en '.well-known/CloudIdVerificationCode.txt' (por favor asegurate de que el texto completo no tenga saltos de línea):",
    "%1$s changed your password on %2$s." : "%1$s cambió tu contraseña en %2$s.",
    "Your password on %s was changed." : "Tu contraseña en %s fue cambiada. ",
    "Your password on %s was reset by an administrator." : "Tu contraseña en %s fue restablecida por un administrador.",
    "Your password on %s was reset." : "Tu contraseña en %s fue restablecida.",
    "Password for %1$s changed on %2$s" : "La contraseña de %1$s fue cambiada en %2$s",
    "Password changed for %s" : "Se cambió la contraseña de %s",
    "If you did not request this, please contact an administrator." : "Si no lo solicitaste, por favor contactá a un administrador. ",
    "Your email address on %s was changed." : "Se cambió tu dirección de correo electrónico en %s. ",
    "Your email address on %s was changed by an administrator." : "Tu dirección de correo electrónico en %s fue cambiada por un adminsitrador. ",
    "Email address for %1$s changed on %2$s" : "Se cambió la dirección de correo electrónico de %1$s en %2$s",
    "Email address changed for %s" : "Se cambió la dirección de correo electrónico de %s",
    "The new email address is %s" : "La nueva dirección de correo electrónico es %s",
    "Your %s account was created" : "Se creó tu cuenta en %s",
    "Welcome aboard" : "Bienvenid@",
    "Welcome aboard %s" : "Bienvenid@, %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bienvenid@ a tu cuenta en %s, podés agregar, proteger, y compartir tus datos.",
    "Your Login is: %s" : "Tu nombre de usuario es: %s",
    "Set your password" : "Establecé tu contraseña",
    "Go to %s" : "Ir a %s",
    "Install Client" : "Instalar cliente",
    "Logged in account must be a sub admin" : "La cuenta conectada debe ser de un subadministrador",
    "Apps" : "Aplicaciones",
    "Personal" : "Personal",
    "Administration" : "Administración",
    "Users" : "Usuarios",
    "Additional settings" : "Configuraciones adicionales",
    "Assistant" : "Asistente",
    "Administration privileges" : "Privilegios de administración",
    "Groupware" : "Software colaborativo",
    "Overview" : "Visión general",
    "Basic settings" : "Configuraciones básicas",
    "Sharing" : "Compartir",
    "Availability" : "Disponibilidad",
    "Calendar" : "Calendario",
    "Personal info" : "Información personal",
    "Mobile & desktop" : "Móvil & escritorio",
    "Artificial Intelligence" : "Inteligencia artificial",
    "Email server" : "Servidor de correo electrónico",
    "Mail Providers" : "Proveedores de correo electrónico",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "El proveedor de correo electrónico permite enviar correos electrónicos directamente a través de la cuenta de correo personal del usuario. En la actualidad, esta funcionalidad se limita a las invitaciones de calendario. Requiere Nextcloud Mail 4.1 y una cuenta de correo electrónico en Nextcloud Mail que coincida con la dirección de correo electrónico del usuario en Nextcloud.",
    "Send emails using" : "Enviar correos electrónicos usando",
    "User's email account" : "Cuenta de correo electrónico del usuario",
    "System email account" : "Cuenta de correo electrónico del sistema",
    "Security & setup checks" : "Revisiones de seguridad y configuración",
    "Background jobs" : "Trabajos en segundo plano",
    "Unlimited" : "Ilimitado",
    "Verifying" : "Verificando",
    "Verifying …" : "Verificando ...",
    "Verify" : "Verificar",
    "Allowed admin IP ranges" : "Rangos de IP permitidos para administración",
    "Admin IP filtering isn't applied." : "No se ha aplicado ningún filtro de IP para administración.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "El parámetro de configuración \"%1$s\" espera un array (se encontró %2$s). No se aplicará la validación de rangos de IP para administración.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "El parámetro de configuración \"%1$s\" contiene rangos de IP inválido(s): \"%2$s\"",
    "Admin IP filtering is correctly configured." : "El filtro de rangos de IP para administración se configuró correctamente.",
    "App directories owner" : "Propietario de los directorios de aplicaciones",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Algunos directorios de aplicaciones pertenecen a un usuario diferente al del servidor web. Esto puede ocurrir si las aplicaciones se instalaron manualmente. Comprobá los permisos de los siguientes directorios de aplicaciones:\n%s",
    "App directories have the correct owner \"%s\"" : "Los directorios de aplicaciones pertenecen al usuario correcto \"%s\"",
    "Brute-force Throttle" : "Limitación de ataques de fuerza bruta",
    "Your remote address could not be determined." : "No pudo determinarse tu dirección remota.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Tu dirección remota fue identificada como \"%s\" y es fuente de un ataque de fuerza bruta, por lo que está siendo limitada, disminuyendo el rendimiento de varias solicitudes. Si la dirección remota no es la tuya, puede ser una señal de que un proxy no está correctamente configurado.",
    "Your remote address \"%s\" is not brute-force throttled." : "Tu dirección remota \"%s\" no está siendo limitada.",
    "Old administration imported certificates" : "Certificados de administración importados antiguos",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "Un trabajo en segundo plano que comprueba los certificados SSL de administración importados todavía está pendiente. Por favor, verificá más tarde.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Hay algunos certificados SSL de administración importados que ya no se usan con Nextcloud 21. Se pueden importar ejecutando el comando \"occ security:certificates:import\" en la línea de comandos. Sus rutas dentro del directorio de datos se muestran a continuación.",
    "Code integrity" : "Integridad del código",
    "Integrity checker has been disabled. Integrity cannot be verified." : "El verificador de integridad está deshabilitado. La integridad no se puede verificar.",
    "No altered files" : "No hay archivos alterados",
    "Some files have not passed the integrity check. {link1} {link2}" : "Algunos archivos no pasaron la verificación de integridad. {link1} {link2}",
    "Cron errors" : "Errores de cron",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "No se pudo ejecutar el trabajo cron a través de la línea de comandos. Se presentaron los siguientes errores técnicos:\n%s",
    "The last cron job ran without errors." : "El último trabajo cron se ejecutó sin errores.",
    "Cron last run" : "Última ejecución de cron",
    "Last background job execution ran %s. Something seems wrong. {link}." : "La última ejecución de trabajos de segundo plano se ejecutó %s. Algo parece estar mal. {link}.",
    "Last background job execution ran %s." : "La última ejecución de trabajos de segundo plano se ejecutó %s.",
    "Data directory protected" : "Directorio de datos protegido",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Tu directorio de datos y tus archivos probablemente se pueden acceder desde internet. El archivo .htaccess no funciona. Es muy recomendable que configures tu servidor web de manera que el directorio de datos no sea accesible, o que lo muevas fuera del directorio raíz de documentos del servidor web.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "No se pudo verificar que el directorio de datos esté protegido. Por favor, chequeá manualmente que tu servidor no permita el acceso al directorio de datos.",
    "Database missing columns" : "Faltan columnas en la base de datos",
    "Missing optional column \"%s\" in table \"%s\"." : "Falta la columna opcional \"%s\" en la tabla \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "A la base de datos le faltan algunas columnas opcionales. Dado que agregar columnas en tablas grandes puede llevar bastante tiempo, no se agregaron automáticamente. Ejecutando manualmente \"occ db:add-missing-columns\" se pueden agregar las columnas faltantes mientras la instancia sigue corriendo. Una vez agregadas las columnas, algunas características podrían mejorar su capacidad de respuesta o la usabilidad.",
    "Database missing indices" : "Faltan índices en la base de datos",
    "Missing indices:" : "Índices faltantes:",
    "\"%s\" in table \"%s\"" : "\"%s\" en la tabla \"%s\"",
    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them." : "Se detectaron algunos índices opcionales faltantes. De vez en cuando se agregan nuevos índices (ya sea por Nextcloud o por las aplicaciones instaladas) para mejorar el rendimiento de la base de datos. Agregar índices algunas veces puede llevar bastante tiempo y afectar temporariamente el rendimiento, así que no se hace automáticamente durante las actualizaciones. Una vez que los índices fueron agregados las consultas a esas tablas deberían ser más rápidas. Usá el comando `occ db:add-missing-indices` para agregarlos.",
    "Database missing primary keys" : "Faltan claves primarias en la base de datos",
    "Missing primary key on table \"%s\"." : "Falta la clave primaria en la tabla \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "A la base de datos le faltan algunas claves primarias. Dado que agregar claves primarias en tablas grandes puede llevar bastante tiempo, no se agregaron automáticamente. Ejecutando manualmente \"occ db:add-missing-primary-keys\" esas claves primarias faltantes se pueden agregar mientras la instancia sigue funcionando.",
    "Database pending bigint migrations" : "Está pendiente la conversión a bigint de la base de datos",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Algunas columnas de la base de datos no fueron convertidas a big int todavía. Dado que cambiar los tipos de columna en tablas grandes puede llevar bastante tiempo, no se cambiaron automáticamente. Ejecutando manualmente \"occ db:convert-filecache-bigint\" se pueden aplicar esos cambios pendientes. Esta operación debe realizarse mientras la instancia está fuera de línea.",
    "Debug mode" : "Modo de depuración",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Esta instancia se está ejecutando en modo de depuración. Habilitá esto únicamente para desarrollo local y no en ambientes de producción.",
    "Debug mode is disabled." : "Modo de depuración deshabilitado.",
    "Default phone region" : "Región predeterminada para números de teléfono",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Tu instalación no tiene una región predeterminada para números de teléfono. Esto es necesario para validar números de teléfono en los ajustes de usuario que no tengan un código internacional. Para permitir números sin código internacional, añadí a tu archivo de configuración el ajuste \"default_phone_region\" con el código regional ISO 3166-1 correspondiente.",
    "Email test" : "Prueba de correo electrónico",
    "Mail delivery is disabled by instance config \"%s\"." : "El envío de correo electrónico está deshabilitado en la configuración de la instancia \"%s\".",
    "Email test was successfully sent" : "La prueba de correo electrónico se envió correctamente",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Todavía no configuraste o verificaste tu servidor de correo electrónico. Por favor, configuralo en la sección \"Ajustes básicos\". Después usá el botón \"Enviar correo\" bajo el formulario para verificar tus ajustes.",
    "Transactional File Locking" : "Bloqueo transaccional de archivos",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "El bloqueo transaccional de archivos está deshabilitado. Esta configuración no está soportada. Puede provocar problemas difíciles de aislar incluyendo la corrupción de archivos. Por favor eliminá la configuración 'filelocking.enabled' => false` de tu archivo config.php para evitar estos problemas.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "El bloqueo transaccional de archivos está habilitado. Para mejorar el rendimiento, por favor configurá memcache, si está disponible.",
    "Forwarded for headers" : "Encabezados Forwarded for",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "La configuración de \"trusted_proxies\" es incorrecta, debería ser un array.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "La configuración de \"trusted_proxies\" es incorrecta, debería ser un array de direcciones IP - opcionalmente con rangos en notación CIDR.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "La configuración del encabezado del proxy inverso es incorrecta. Esto es un problema de seguridad y puede permitir que un atacante muestre a Nextcloud una dirección IP falsa.",
    "Your IP address was resolved as %s" : "Tu dirección IP se resolvió como %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "La configuración de la cabecera del proxy inverso es incorrecta, o estás tratando de acceder a Nextcloud desde un proxy de confianza. En caso contrario, esto es un problema de seguridad y puede permitir que un atacante muestre a Nextcloud una dirección IP falsa.",
    "HTTPS access and URLs" : "Acceso HTTPS y URLs",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Se está accediendo al sitio de manera insegura mediante HTTP. Se recomienda encarecidamente que configures tu servidor para exigir HTTPS. ¡De no hacerlo algunas funciones importantes de la web, como \"copiar al portapapeles\" o \"service workers\", no van a funcionar!",
    "Accessing site insecurely via HTTP." : "Accediendo al sitio de manera insegura mediante HTTP.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Estás accediendo a tu instancia a través de una conexión segura, sin embargo, tu instancia está generando URLs inseguras. Esto probablemente quiere decir que tu instancia está detrás de un proxy inverso y que los valores de configuración `overwrite*` para Nextcloud no están bien configurados.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Tu instancia está generando URLs inseguras. Si estás accediendo a tu instancia a través de HTTPS,  probablemente significa que tu instancia está detrás de un proxy inverso y que los valores de configuración `overwrite*` para Nextcloud no están bien configurados.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "Estás accediendo a tu instancia a través de una conexión segura, y tu instancia está generando URLs seguras.",
    "Internet connectivity" : "Conexión a Internet",
    "Internet connectivity is disabled in configuration file." : "La conexión a Internet está deshabilitada en el archivo de configuración.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Este servidor no tiene una conexión a Internet que funcione: hubo múltiples puntos de acceso que no pudieron alcanzarse. Algunas funciones como montar almacenamiento externo, notificaciones sobre actualizaciones o instalación de aplicaciones de terceros no funcionarán. Es posible que el acceso a archivos de forma remota y el envío de correos electrónicos de notificación tampoco funcionen. Establecé una conexión desde este servidor a Internet para contar con todas las funciones.",
    "JavaScript modules support" : "Soporte de módulos JavaScript",
    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "No se pudo chequear que JavaScript esté soportado. Por favor solucioná el problema o confirmá manualmente si tu servidor web sirve archivos `.mjs` utilizando el tipo MIME JavaScript.",
    "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "Tu servidor web no sirve archivos `.mjs` utilizando el tipo MIME JavaScript. Esto va a causar problemas con algunas apps, impidiendo que los navegadores ejecuten los archivos JavaScript. Tenés que configurar tu servidor web para servir archivos `.mjs` ya sea con el tipo MIME `text/javascript` o `application/javascript`.",
    "JavaScript source map support" : "Soporte de mapa fuente de JavaScript",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "Tu servidor web no está configurado para servir archivos `.js.map`. Sin estos archivos, los mapas de fuente JavaScript no funcionarán apropiadamente, haciendo más difícil la resolución y depuración de problemas que puedan surgir.",
    "Old server-side-encryption" : "Cifrado en el servidor obsoleto",
    "Disabled" : "Deshabilitado",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "El formato obsoleto de cifrado en el servidor está activado. Te recomendamos deshabilitar esto.",
    "Logging level" : "Nivel de registro",
    "The %1$s configuration option must be a valid integer value." : "La opción de configuración %1$s debe ser un valor entero válido.",
    "Maintenance window start" : "Inicio de la ventana de mantenimiento",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "El servidor no tiene configurado un tiempo de inicio para la ventana de mantenimiento. Esto significa que los trabajos diarios en segundo plano que consumen recursos de manera intensiva van a ejecutarse durante el tiempo regular de uso. Te recomendamos establecerlo a una franja horaria de poco uso, para que los usuarios no sufran el impacto de la ejecución de estas tareas intensivas.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "La ventana de mantenimiento para ejecutar trabajos intensivos en segundo plano es entre {start}:00 UTC y {end}:00 UTC",
    "Memcache" : "Memcache",
    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "Se configuró memcached como caché distribuido, pero en PHP está instalado el módulo equivocado (memcache). Por favor, instalá en PHP el módulo \"memcached\".",
    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "Se configuró memcached como caché distribuido, pero no está instalado en PHP. Por favor, instalá en PHP el módulo \"memcached\".",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "No hay configurado ningún caché en memoria. Para mejorar el rendimiento, por favor configurá memcache, si está disponible.",
    "Failed to write and read a value from local cache." : "Fallo al escribir y leer un valor de la caché local.",
    "Failed to write and read a value from distributed cache." : "Fallo al escribir y leer un valor de la caché distribuida.",
    "Configured" : "Configurado",
    "Mimetype migrations available" : "Están disponibles las migraciones del tipo MIME",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "Hay disponible una o más migraciones del tipo MIME. De vez en cuando se agregan nuevos tipos MIME para manejar de manera más adecuada ciertos tipos de archivo. Migrar los tipos MIME puede llevar bastante tiempo en instancias grandes, así que no se hace de manera automática durante las actualizaciones. Usá el comando `occ maintenance:repair --include-expensive` para realizar las migraciones.",
    "MySQL row format" : "Formato de filas de MySQL",
    "You are not using MySQL" : "No estás usando MySQL",
    "None of your tables use ROW_FORMAT=Compressed" : "Ninguna de tus tablas usa ROW_FORMAT=Compressed",
    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "Hay un formato de filas incorrecto en tu base de datos. ROW_FORMAT=Dynamic ofrece las mejores prestaciones de base de datos para Nextcloud. Por favor, actualizá el formato de filas de la siguiente lista: %s.",
    "MySQL Unicode support" : "Soporte Unicode de MySQL",
    "MySQL is used as database and does support 4-byte characters" : "Usando MySQL como base de datos, que soporta caracteres de 4 bytes",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "Usando MySQL como base de datos, pero no soporta caracteres de 4 bytes. Para poder manejar caracteres de 4 bytes (como los emojis) sin problemas en los nombres de archivo o comentarios, por ejemplo, te recomendamos habilitar el soporte de 4 bytes en MySQL.",
    "OCS provider resolving" : "Resolución de proveedor OCS",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "No se pudo verificar que tu servidor web resuelve apropiadamente los URLs de proveedores OCS y OCM.",
    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "Tu servidor web no está configurado correctamente para resolver %1$s.\nEsto probablemente se debe a que la configuración del servidor web no se actualizó para entregar esta carpeta directamente.\nPor favor, compará tu configuración con las reglas de re-escritura por defecto en \".htaccess\" para Apache o la que se proporcionó en la documentación de Nginx\nEn Nginx las líneas que empiezan con \"location ~\" son las que habitualmente necesitan actualizarse.",
    "Overwrite CLI URL" : "Sobreescribir el URL del CLI",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "La opción \"overwrite.cli.url\" en tu config.php está correctamente establecida como \"%s\".",
    "PHP default charset" : "Conjunto de caracteres predeterminado de PHP",
    "PHP configuration option \"default_charset\" should be UTF-8" : "La opción de configuración de PHP \"default_charset\" debería ser UTF-8",
    "Freetype" : "FreeType",
    "Supported" : "Soportado",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Tu PHP no tiene soporte FreeType, lo que resulta en fallas en las imágenes de perfil y en la interfaz de configuraciones.",
    "PHP file size upload limit" : "Límite de carga de archivos en PHP",
    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "El upload_max_filesize de PHP es demasiado bajo. Se recomienda un tamaño de al menos %1$s. Valor actual: %2$s.",
    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "El post_max_size de PHP es demasiado bajo. Se recomienda un tamaño de al menos %1$s. Valor actual: %2$s.",
    "The PHP max_input_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "El max_input_time de PHP es demasiado bajo. Se recomienda un tiempo de al menos %1$s. Valor actual: %2$s.",
    "The PHP max_execution_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "El max_execution_time de PHP es demasiado bajo. Se recomienda un tiempo de al menos %1$s. Valor actual: %2$s.",
    "PHP memory limit" : "Límite de memoria de PHP",
    "The PHP memory limit is below the recommended value of %s. Some features or apps - including the Updater - may not function properly." : "El límite de memoria PHP está por debajo del valor recomendado de %s. Es posible que algunas funciones o aplicaciones -incluyendo el Actualizador- no funcionen correctamente.",
    "PHP modules" : "Módulos de PHP",
    "required for SFTP storage and recommended for WebAuthn performance" : "necesario para el almacenamiento SFTP y recomendado para el rendimiento de WebAuthn",
    "PHP opcache" : "opcache de PHP",
    "Architecture" : "Arquitectura",
    "64-bit" : "64 bits",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Su base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Foto de perfil, nombre completo, correo electrónico, número de teléfono, dirección, sitio web, Twitter, organización, rol, titular, biografía y si tu perfil está habilitado",
    "Enable" : "Habilitar",
    "None" : "Ninguno",
    "Allow apps to use the Share API" : "Permitir que las aplicaciones usen el API para Compartir",
    "Allow resharing" : "Permitir volver a compartir",
    "Allow sharing with groups" : "Permitir compartir con grupos",
    "Restrict users to only share with users in their groups" : "Limitar a los usuarios a sólo compartir con otros usuarios en sus grupos",
    "Allow public uploads" : "Permitir cargas públicas",
    "Always ask for a password" : "Siempre pedir una contraseña",
    "Enforce password protection" : "Forzar protección de contraseñas",
    "Enforce expiration date" : "Forzar fecha de expiración",
    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto se mostrará en la página de carga del enlace público cuando la lista de archivos esté oculta.",
    "Two-Factor Authentication" : "Autenticación en dos pasos",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "La autenticación en dos pasos puede aplicarse a todas las cuentas y a grupos específicos. Si no tienen configurado un proveedor de dos factores, no podrán iniciar sesión en el sistema.",
    "Limit to groups" : "Limitar a grupos",
    "Save changes" : "Guardar cambios",
    "Remove" : "Eliminar",
    "Featured" : "Destacado",
    "Icon" : "Ícono",
    "Name" : "Nombre",
    "Version" : "Versión",
    "Level" : "Nivel",
    "Actions" : "Acciones",
    "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
    "Failed to create group" : "No se pudo crear el grupo",
    "Groups" : "Grupos",
    "Creating group…" : "Creando grupo…",
    "Create group" : "Crear grupo",
    "Group name" : "Nombre del grupo",
    "Please enter a valid group name" : "Ingresá un nombre de grupo válido",
    "Loading" : "Cargando",
    "Type" : "Escribir",
    "Display Name" : "Nombre a desplegar",
    "Learn more" : "Conozca más",
    "Confirm" : "Confirmar",
    "Cancel" : "Cancelar",
    "Description" : "Descripción",
    "View in store" : "Ver en la tienda",
    "Visit website" : "Visitá el sitio web",
    "Admin documentation" : "Documentación del administrador",
    "Developer documentation" : "Documentación del desarrollador",
    "Details" : "Detalles",
    "All" : "Todos",
    "No results" : "No hay resultados",
    "Update to {version}" : "Actualizar a {version}",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
    "Categories" : "Categoría",
    "Resources" : "Recursos",
    "Documentation" : "Documentación",
    "Report a bug" : "Reporte un tema",
    "Request feature" : "Solicitar una funcionalidad",
    "Ask questions or discuss" : "Hacer una pregunta o comentar",
    "Rate" : "Calificar",
    "Changelog" : "Bitácora de cambios",
    "Google Chrome for Android" : "Google Chrome para Android",
    "{productName} Android app" : "{productName} aplicación Android",
    "This session" : "Esta sesión",
    "Allow filesystem access" : "Permitir acceso al sistema de archivos",
    "Rename" : "Renombrar",
    "Revoke" : "Revocar",
    "Device" : "Dispositivo",
    "Last activity" : "Última actividad",
    "Devices & sessions" : "Dispositivos y sesiones",
    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de escritorio y móviles conectados actualmente a tu cuenta.",
    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
    "App name" : "Nombre de la aplicación",
    "Create new app password" : "Crear una nueva contraseña de aplicación",
    "Login" : "Inicio de sesión",
    "Password" : "Contraseña",
    "Unable to update profile default setting" : "No se pudo actualizar la configuración por defecto del perfil",
    "Profile" : "Perfil",
    "Enable or disable profile by default for new accounts." : "Habilitar o deshabilitar el perfil por defecto para cuentas nuevas.",
    "Password confirmation is required" : "Se requiere la confirmación de la contraseña",
    "Failed to save setting" : "No se pudo guardar la configuración",
    "{app}'s declarative setting field: {name}" : "Campo de configuración declarativa de {app}: {name}",
    "Unable to update server side encryption config" : "No se pudo actualizar la configuración de cifrado en el servidor",
    "Server-side encryption" : "Cifrado en el servidor",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "El cifrado en el servidor permite cifrar archivos que se suban a este servidor. Esto trae limitaciones como una penalización en el rendimiento, así que habilitalo sólo si es necesario.",
    "To encrypt all existing files run this OCC command:" : "Para cifrar todos los archivos existentes, ejecutá este comando OCC:",
    "Enable server-side encryption" : "Habilitar cifrado en el servidor",
    "Disabling server side encryption is only possible using OCC, please refer to the documentation." : "Sólo es posible deshabilitar el cifrado en el servidor usando OCC, por favor consultá la documentación.",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No hay ningún módulo de cifrado cargado, por favor habilitá algún modulo de cifrado en el menú de aplicaciones.",
    "Select default encryption module:" : "Seleccioná el módulo de cifrado por defecto:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Necesitás migrar tus claves de cifrado del cifrado antiguo (ownCloud <= 8.0) al nuevo. Activá el \"Módulo de cifrado predeterminado\" y ejecutá {command}",
    "Cancel encryption" : "Cancelar cifrado",
    "Enable encryption" : "Habilitar cifrado",
    "Confirm enabling encryption" : "Confirmar la habilitación del cifrado",
    "Please read carefully before activating server-side encryption:" : "Leé detenidamente antes de activar el cifrado en el servidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que el cifrado está habilitado, todos los archivos subidos al servidor desde ese momento en adelante se cifrarán en el servidor. Sólo será posible deshabilitar el cifrado en una fecha posterior si el módulo de cifrado activado soporta esa función, y todas las precondiciones (por ejemplo, el establecimiento de una clave de recuperación) se cumplen.",
    "By default a master key for the whole instance will be generated. Please check if that level of access is compliant with your needs." : "Por defecto, se generará una clave maestra para toda la instancia. Por favor verificá que ese nivel de acceso cubra tus necesidades.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "El cifrado por sí solo no garantiza la seguridad del sistema. Por favor, leé la documentación para más información sobre cómo funciona la aplicación de cifrado y los casos de uso soportados.",
    "Be aware that encryption always increases the file size." : "Tené presente que el cifrado siempre aumenta el tamaño de los archivos.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es una buena idea crear copias de seguridad de tus datos, en el caso del cifrado asegurate de tener una copia de seguridad de las claves de cifrado junto con tus datos.",
    "Refer to the admin documentation on how to manually also encrypt existing files." : "Consultá la documentación del administrador para saber cómo cifrar manualmente también los archivos existentes.",
    "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final. ¿Realmente querés activar el cifrado?",
    "Please confirm the group removal" : "Por favor confirmá la eliminación del grupo",
    "Submit" : "Enviar",
    "Rename group" : "Cambiar nombre del grupo",
    "Current password" : "Contraseña actual",
    "New password" : "Nueva contraseña",
    "Choose your profile picture" : "Elegí tu foto del perfil",
    "Please select a valid png or jpg file" : "Por favor, seleccioná un archivo PNG o JPG válido",
    "Error setting profile picture" : "Error al establecer la foto del perfil",
    "Error cropping profile picture" : "Error al recortar la foto del perfil",
    "Error saving profile picture" : "Error al guardar la foto del perfil",
    "Error removing profile picture" : "Error al eliminar la foto del perfil",
    "Your profile picture" : "Tu foto del perfil",
    "Upload profile picture" : "Subir foto del perfil",
    "Choose profile picture from Files" : "Elegir foto del perfil desde Archivos",
    "Remove profile picture" : "Eliminar la foto del perfil",
    "The file must be a PNG or JPG" : "El archivo debe ser PNG o JPG",
    "Picture provided by original account" : "Imagen proporcionadoa por la cuenta original ",
    "Set as profile picture" : "Establecer como foto del perfil",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Tené en cuenta que puede llevar hasta 24 horas para que tu foto del perfil se actualice en todos lados.",
    "Your biography. Markdown is supported." : "Tu biografía. Se admite Markdown.",
    "Unable to update date of birth" : "No se pudo actualizar tu fecha de nacimiento",
    "Enter your date of birth" : "Ingresá tu fecha de nacimiento",
    "You are using {s}{usage}{/s}" : "Estás usando {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Estás usando {s}{usage}{/s} de {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "You are a member of the following groups:" : "Sos miembro de los siguientes grupos:",
    "Your full name" : "Tu nombre completo",
    "Unable to update primary email address" : "No se pudo actualizar la dirección de correo electrónico principal",
    "Unable to delete additional email address" : "No se pudo eliminar la dirección de correo electrónico adicional",
    "No email address set" : "No se ha establecido la dirección de correo electrónico",
    "Email options" : "Opciones de correo electrónico",
    "Options for additional email address {index}" : "Opciones para la dirección de correo electrónico adicional {index}",
    "Remove primary email" : "Eliminar correo electrónico principal",
    "Delete email" : "Eliminar correo electrónico",
    "This address is not confirmed" : "Esta dirección no está confirmada",
    "Unset as primary email" : "Remover como correo electrónico principal",
    "Set as primary email" : "Establecer como correo electrónico principal",
    "Additional email address {index}" : "Dirección de correo electrónico adicional {index}",
    "Unable to delete primary email address" : "No se pudo eliminar la dirección de correo electrónico principal",
    "Unable to add additional email address" : "No se pudo agregar la dirección de correo electrónico adicional",
    "Unable to update additional email address" : "No se pudo actualizar la dirección de correo electrónico adicional",
    "Primary email for password reset and notifications" : "Correo electrónico principal para restablecer la contraseña y notificaciones",
    "Your handle" : "Tu usuario",
    "Derived from your locale ({weekDayName})" : "Obtenido de tu locale ({weekDayName})",
    "Unable to update first day of week" : "No se pudo modificar el primer día de la semana",
    "Day to use as the first day of week" : "Primer día de la semana",
    "Your headline" : "Tu titular",
    "No language set" : "No hay ningún idioma configurado",
    "Unable to update language" : "No se pudo actualizar tu idioma",
    "Languages" : "Idiomas",
    "Help translate" : "Ayudá a traducir",
    "No locale set" : "No hay ninguna configuración regional",
    "Unable to update locale" : "No se pudo actualizar la configuración regional",
    "Locales" : "Configuración regional",
    "Week starts on {firstDayOfWeek}" : "La semana empieza el {firstDayOfWeek}",
    "Your city" : "Tu ciudad",
    "Your organisation" : "Tu organización",
    "Your phone number" : "Tu número de teléfono",
    "Edit your Profile visibility" : "Editar la visibilidad de tu perfil",
    "Unable to update profile enabled state" : "No se pudo actualizar la habilitación del perfil",
    "Enable profile" : "Habilitar perfil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Se respetará en tu perfil el ajuste más restrictivo entre visibilidad y alcance. Por ejemplo, si la visibilidad está configurada en \"Mostrar a todos\" y el alcance en \"Privado\", los ajustes de \"Privado\" se respetarán.",
    "Unable to update visibility of {displayId}" : "No se pudo actualizar la visibilidad de {displayId}",
    "she/her" : "ella",
    "he/him" : "él",
    "they/them" : "elle",
    "Your role" : "Tu rol",
    "Timezone" : "Zona horaria",
    "Your X (formerly Twitter) handle" : "Tu usuario de X (anteriormente Twitter)",
    "Your website" : "Tu sitio web",
    "Add" : "Agregar",
    "Change" : "Cambiar",
    "Delete" : "Eliminar",
    "Email" : "Correo electrónico",
    "Quota" : "Cuota",
    "Language" : "Idioma",
    "Avatar" : "Avatar",
    "Account name" : "Nombre de la cuenta",
    "Group admin for" : "Administrador del grupo para",
    "Account backend" : "Backend de la cuenta",
    "Storage location" : "Úbicación del almacenamiento",
    "First login" : "Primer inicio de sesión",
    "Last login" : "Último inicio de sesión",
    "Account actions" : "Acciones de la cuenta",
    "{size} used" : "{size} usados",
    "Delete account" : "Borrar cuenta",
    "Disconnect all devices and delete local data" : "Desconectar todos los dispositivos y eliminar los datos locales",
    "Disable account" : "Deshabilitar la cuenta",
    "Enable account" : "Habilitar la cuenta",
    "Resend welcome email" : "Volver a enviar el correo electrónico de bienvenida",
    "Remote wipe of devices" : "Borrado remoto de dispositivos",
    "Wipe {userid}'s devices" : "Borrar los dispositivos de {userid}",
    "Wiped {userid}'s devices" : "Se borraron los dispositivos de {userid}",
    "Failed to update line manager" : "No se pudo actualizar el superior inmediato",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Eliminar completamente la cuenta de {userid}, incluyendo todos sus archivos personales, datos de las aplicaciones, etc.",
    "Account deletion" : "Eliminación de la cuenta",
    "Delete {userid}'s account" : "Eliminar la cuenta de {userid}",
    "Display name was successfully changed" : "Se cambió correctamente el nombre para mostrar",
    "Password can't be empty" : "La contraseña no puede estar en blanco",
    "Password was successfully changed" : "La contraseña se cambió correctamente",
    "Email can't be empty" : "El correo electrónico no puede estar en blanco",
    "Email was successfully changed" : "El correo electrónico se cambió correctamente",
    "Welcome mail sent!" : "¡Correo electrónico de bienvenida enviado!",
    "Change display name" : "Cambiar el nombre a mostrar",
    "Set new password" : "Establecer nueva contraseña",
    "You do not have permissions to see the details of this account" : "No tenés permisos para ver los detalles de esta cuenta",
    "Set new email address" : "Establecer nueva dirección de correo electrónico",
    "Add account to group" : "Agregar cuenta al grupo",
    "Set account as admin for" : "Establecer cuenta como administrador de",
    "Select account quota" : "Seleccionar la cuota de la cuenta",
    "Set the language" : "Establecer el lenguaje",
    "Toggle account actions menu" : "Alternar menú de acciones de cuenta",
    "Done" : "Terminado",
    "Edit" : "Editar",
    "Account management settings" : "Configuración de administración de cuentas",
    "Visibility" : "Visibilidad",
    "Show language" : "Mostrar lenguaje",
    "Show account backend" : "Mostrar el backend de la cuenta",
    "Show storage path" : "Mostrar la ruta de almacenamiento",
    "Show first login" : "Mostrar primer inicio de sesión",
    "Show last login" : "Mostrar último inicio de sesión",
    "Sorting" : "Orden",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "La configuración de sistema fuerza a que los grupos sean ordenados por nombre. Esto también impide mostrar la cantidad de miembros.",
    "Group list sorting" : "Ordenamiento de la lista de grupos",
    "By member count" : "Por cantidad de miembros",
    "By name" : "Por nombre",
    "Send email" : "Enviar correo electrónico",
    "Send welcome email to new accounts" : "Enviar un correo electrónico de bienvenida a usuarios nuevos",
    "Defaults" : "Valores por defecto",
    "Default quota" : "Cuota predeterminada",
    "Select default quota" : "Seleccionar la cuota predeterminada",
    "Server error while trying to complete WebAuthn device registration" : "Error en el servidor al intentar completar el registro del dispositivo WebAuthn",
    "Passwordless authentication requires a secure connection." : "La autenticación sin contraseña requiere una conexión segura.",
    "Add WebAuthn device" : "Agregar dispositivo WebAuthn",
    "Please authorize your WebAuthn device." : "Autorizá tu dispositivo WebAuthn.",
    "Unnamed device" : "Dispositivo sin nombre",
    "Passwordless Authentication" : "Autenticación sin contraseña",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Configurá tu cuenta para la autenticación sin contraseña siguiendo el estándar FIDO2.",
    "No devices configured." : "No hay ningún dispositivo configurado.",
    "The following devices are configured for your account:" : "Los siguientes dispositivos están configurados para tu cuenta:",
    "Your browser does not support WebAuthn." : "Tu navegador no admite WebAuthn.",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
    "Send mode" : "Modo de envío",
    "Encryption" : "Cifrado",
    "Sendmail mode" : "Modo Sendmail",
    "From address" : "Desde la dirección",
    "Domain" : "Dominio",
    "Server address" : "Dirección del servidor",
    "Host" : "Servidor",
    "Port" : "Puerto",
    "Authentication" : "Autenticación",
    "Authentication required" : "Autenticación requerida",
    "Saving…" : "Guardando...",
    "Security & setup warnings" : "Advertencias de seguridad y configuración",
    "Try again" : "Inténtalo de nuevo",
    "All checks passed." : "Todas las verificaciones fueron exitosas.",
    "There are some errors regarding your setup." : "Hay algunos errores en tu configuración.",
    "There are some warnings regarding your setup." : "Hay algunas advertencias en tu configuración.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, usted puede hacer ajustes finos al comportamiento de compartir. Favor de consultar la documentación para más información. ",
    "You need to enable the File sharing App." : "Tenés que habilitar la aplicación Compartir archivos.",
    "App Store" : "Tienda de aplicaciones",
    "Loading app list" : "Cargando la lista de aplicaciones",
    "Loading categories" : "Cargando categorías",
    "Developer documentation ↗" : "Documentación del desarrollador ↗",
    "Version {version}, {license}-licensed" : "Versión {version}, bajo licencia {license}",
    "Version {version}" : "Versión {version}",
    "Apply" : "Aplicar",
    "All accounts" : "Todas las cuentas",
    "Admins" : "Administradores",
    "Account group: {group}" : "Grupo de cuentas: {group}",
    "Account management" : "Administración de cuentas",
    "Location" : "Ubicación",
    "Profile picture" : "Foto del perfil",
    "About" : "Acerca de",
    "Date of birth" : "Fecha de nacimiento",
    "Full name" : "Nombre completo",
    "Additional email" : "Correo electrónico adicional",
    "Fediverse (e.g. Mastodon)" : "Fediverso (p.ej. Mastodon)",
    "Headline" : "Títular",
    "Organisation" : "Organización",
    "Phone number" : "Número de teléfono",
    "Pronouns" : "Pronombres",
    "Role" : "Rol",
    "X (formerly Twitter)" : "X (anteriormente Twitter)",
    "Website" : "Sitio web",
    "Profile visibility" : "Visibilidad del perfil",
    "Locale" : "Configuración regional",
    "First day of week" : "Primer día de la semana",
    "Private" : "Privado",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Sólo visible para las personas que coincidan con la integración del número de teléfono a través de Talk en el móvil",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "No está disponible porque esta propiedad es necesaria para la funcionalidad básica, incluyendo el compartir archivos y las invitaciones de calendario",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Sólo visible para personas en esta instancia e invitados",
    "Federated" : "Federado",
    "Only synchronize to trusted servers" : "Sincronizar sólo con servidores de confianza",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "No está disponible porque la federación está deshabilitada para tu cuenta. Ponete en contacto con el administrador del sistema si tenés alguna duda.",
    "Published" : "Publicado",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza y con la libreta de direcciones global y pública",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "No está disponible porque no está permitida la publicación de datos específicos de cuentas en el servidor de búsqueda. Ponete en contacto con el administrador del sistema si tenés alguna duda",
    "Discover" : "Descubrí",
    "Your apps" : "Tus aplicaciones",
    "Active apps" : "Aplicaciones activas",
    "Disabled apps" : "Aplicaciones deshabilitadas",
    "Updates" : "Actualizaciones",
    "App bundles" : "Paquetes de aplicaciones",
    "Featured apps" : "Aplicaciones destacadas",
    "Supported apps" : "Aplicaciones soportadas",
    "Show to everyone" : "Visible para todos",
    "Show to logged in accounts only" : "Visible únicamente para usuarios conectados",
    "Hide" : "Invisible",
    "Manually installed apps cannot be updated" : "Las aplicaciones instaladas manualmente no pueden ser actualizadas",
    "Health checking" : "Revisión de salud del servidor",
    "Deploy and Enable" : "Desplegar y habilitar",
    "Download and enable" : "Descargar y habilitar",
    "Disable" : "Deshabilitar",
    "Allow untested app" : "Permitir aplicación no probada",
    "The app will be downloaded from the App Store" : "La aplicación será descargada de la tienda de aplicaciones",
    "Unknown" : "Desconocido",
    "Never" : "Nunca",
    "Could not register device: Network error" : "No se pudo registrar el dispositivo: error de red",
    "Could not register device: Probably already registered" : "No se pudo registrar el dispositivo: es probable que ya esté registrado",
    "Could not register device" : "No se pudo registrar el dispositivo",
    "An error occurred during the request. Unable to proceed." : "Ocurrió un error durante la solicitud. No se puede continuar.",
    "The app has been enabled but needs to be updated." : "La aplicación ha sido habilitada pero necesita actualizarse.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: Esta aplicación no se puede habilitar porque genera inestabilidad en el servidor",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación está habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
    "Do you really want to wipe your data from this device?" : "¿Estás seguro de querer borrar tus datos de este dispositivo?",
    "Confirm wipe" : "Confirmar borrado",
    "Could not delete the app token" : "No se pudo eliminar el token de aplicación",
    "Error while wiping the device with the token" : "Error al borrar el dispositivo con el token",
    "Error while updating device token name" : "Error al actualizar el nombre del token de dispositivo",
    "Error while updating device token scope" : "Error al actualizar el alcance del token de dispositivo",
    "Could not set group sorting" : "No se pudo establecer el ordenamiento de grupos",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Hubo demasiadas solicitudes desde tu red. Volvé a intentarlo más tarde o ponete en contacto con tu administrador si se trata de un error.",
    "Error" : "Error",
    "Account documentation" : "Documentación de la cuenta",
    "Administration documentation" : "Documentación de administración",
    "Forum" : "Foro",
    "Nextcloud help & privacy resources" : "Ayuda de Nextcloud y recursos de privacidad",
    "General documentation" : "Documentación general",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Políticas de privacidad",
    "Reasons to use Nextcloud in your organization" : "Motivos para usar Nextcloud en tu organización",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Me gusta en nuestra página de Facebook",
    "Follow us on X" : "Seguinos en X",
    "Follow us on Mastodon" : "Seguinos en Mastodon",
    "Check out our blog" : "Visitá nuestro blog",
    "Subscribe to our newsletter" : "Suscribite a nuestro boletín",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Esta versión comunitaria de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles.",
    "Open documentation" : "Abrir la documentación",
    "Use a second factor besides your password to increase security for your account." : "Usá un segundo factor además de tu contraseña para aumentar la seguridad de tu cuenta.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si usás aplicaciones de terceros para conectarte a Nextcloud, por favor asegurate de crear y configurar una contraseña de app para cada una antes de activar la autenticación en dos pasos.",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña aceptable",
    "Good password" : "Buena contraseña",
    "Strong password" : "Contraseña fuerte",
    "Group list is empty" : "La lista de grupos está vacía",
    "Unable to retrieve the group list" : "No fue posible recuperar la lista de grupos",
    "Logged in account must be a subadmin" : "La cuenta conectada debe ser de un subadministrador",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En caso de pérdida del dispositivo o salida de la organización, esto puede borrar de forma remota los datos de Nextcloud de todos los dispositivos asociados con {userid}. Funciona únicamente si los dispositivos están conectados a Internet.",
    "Loading account …" : "Cargando cuenta ...",
    "Adding your device …" : "Agregando tu dispositivo...",
    "Sending…" : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "For performance reasons, when you enable encryption on a Nextcloud server only new and changed files are encrypted." : "Por razones de rendimiento, cuando actives el cifrado en un servidor Nextcloud sólo se cifrarán los archivos nuevos y modificados.",
    "{progress}% Deploying …" : "Desplegando {progress}%",
    "{progress}% Initializing …" : "Inicializando {progress}%",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta aplicación no está marcada como compatible con tu versión de Nextcloud. Si continuás podrás instalar la aplicación, pero tené en cuenta que podría no funcionar según lo esperado.",
    "None/STARTTLS" : "Ninguno/STARTTLS",
    "SSL" : "SSL",
    "Credentials" : "Credenciales",
    "SMTP Login" : "Inicio de sesión SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Save" : "Guardar",
    "Test and verify email settings" : "Probar y verificar la configuración del correo electrónico",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Es importante para la seguridad y rendimiento de tu instancia que todo esté configurado correctamente. Para ayudarte con eso estamos haciendo algunas comprobaciones automáticas. Consultá la documentación para mayor información.",
    "Checking for system and security issues." : "Comprobando problemas del sistema y de seguridad.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Por favor, volvé a consultar las <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guías de instalación ↗</a>, y comprobá posibles errores y advertencias en el <a href=\"%2$s\">registro</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Revisá la seguridad de tu Nextcloud usando <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nuestro escáner de seguridad ↗</a>."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
